package gui;

import audio.BlueAudio;
import common.CommonVariables;
import java.io.IOException;
import javax.microedition.lcdui.Canvas;
import javax.microedition.lcdui.Graphics;
import javax.microedition.lcdui.Image;

/**
 *
 * @author sumanta
 */
public class BlueSplash
    extends Canvas
    implements Runnable
{
    private final BlueMIDlet midlet;
    private Image splashImage;
    private volatile boolean dismissed = false;


    BlueSplash(BlueMIDlet midlet)
    {
        this.midlet = midlet;
        try {
            splashImage = Image.createImage("/splash.png");
            //also start the music player
            if(CommonVariables.audio == null) 
                CommonVariables.audio = new BlueAudio(midlet);
            CommonVariables.audio.setMusicPath("/audio/title.mid");
            CommonVariables.audio.start();
            new Thread(this).start();
        } catch (IOException ex) {
            ex.printStackTrace();
        }
    }


    public void run()
    {
        synchronized(this)
        {
            try
            {
                wait(3000L);   // 1.5 seconds
            }
            catch (InterruptedException e)
            {
                // can't happen in MIDP: no Thread.interrupt method
            }
        }
        dismiss();
    }


    public void paint(Graphics g)
    {
        int width = getWidth();
        int height = getHeight();
        g.setColor(0x00FFFFFF);  // white
        g.fillRect(0, 0, width, height);

        g.setColor(0x00FF0000);  // red
        g.drawRect(1, 1, width-2, height-2);  // red border one pixel from edge

        if (splashImage != null)
        {
            g.drawImage(splashImage,
                        width/2,
                        height/2,
                        Graphics.VCENTER | Graphics.HCENTER);
            splashImage = null;
//            midlet.splashScreenPainted();
        }
    }


    public void keyPressed(int keyCode)
    {
        dismiss();
    }


    private synchronized void dismiss()
    {
        if (!dismissed)
        {
            dismissed = true;
            midlet.splashScreenDone();
        }
    }
}
